Getting In Touch With Us
========================

We are working hard to make coala a top choice for static code analysis.
coala is a place where people from all over the world are part of a friendly,
growing community. If you want to get in touch with us, you can do any of the
following things:

-  Join us on our `gitter channel <https://coala.io/chat>`__
   where we are very active and happy to help you!
-  Subscribe to our `mailing lists <https://github.com/coala/coala/wiki/Mailing-Lists>`__.
-  Open an issue. Whether you want a new feature for coala or you have found
   a bug, just file `an issue <https://github.com/coala/coala/issues>`__
   and we will check it out. In case of long discussion, you should create
   a new issue with clearly defined task!
-  Give us feedback. If you think we're doing something useless or something
   amazing, let us know by dropping a message on gitter or a mail on our
   mailing lists!
-  If you believe someone is violating the `code of conduct <http://docs.coala.io/en/latest/Help/FAQ.html#what-is-coala-community-code-of-conduct>`__
   , we ask that you report it by emailing ``community AT coala DOT io``.

We appreciate any help. (Partially with words, partially with chocolate
if you live near Hamburg or join us at conferences.)

Modularity, clean good code as well as a high usability for both users
and developers of analyse routines (called bears) stand in the
foreground of the development. We will not speed up our development if
it needs sacrificing any aspect of quality.
